<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source> About Boomaga</source>
        <translation> Über Boomaga</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autoren</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>Vielen Dank</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Übersetzungen</translation>
    </message>
    <message>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <source>Boomaga provides a virtual printer for CUPS. This can be used for print preview or for print booklets.</source>
        <translation>Boomaga stellt einen virtuellen Drucker für CUPS zur Verfügung. Dieser kann als Druckvorschau oder zum Drucken von Booklets verwendet werden.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation>Copyright: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation>Homepage: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation>Lizenz: %1</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation>Wer mit dem Entwickler-Team zusammenarbeiten möchte, bitte &lt;a %1&gt;hier melden&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation>Besonderen Dank an:</translation>
    </message>
    <message>
        <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
        <translation>Wenn Du zur Übersetzung beitragen möchtest, würden wir uns freuen, dich im Übersetzungsteam auf &lt;a %1&gt;Transifex&lt;/a&gt; begrüßen zu dürfen.</translation>
    </message>
    <message>
        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
        <translation>Boomaga wird vom &lt;a %1&gt;Boomaga-Team und Beitragenden&lt;/a&gt; auf GitHub entwickelt.</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Divide your long booklets into smaller sub-booklets for printing.</source>
        <translation>Große Broschüren (zum Drucken) aufteilen</translation>
    </message>
    <message>
        <source>Print as sub-booklets</source>
        <translation>Broschürendruck aufteilen (sub-booklets)</translation>
    </message>
    <message>
        <source>Maximum number of sheets in your sub-booklet.</source>
        <translation>Maximale Blätter pro sub-booklet.</translation>
    </message>
    <message>
        <source>Sheets per sub-booklet:</source>
        <translation>Blätter pro sub-booklet:</translation>
    </message>
    <message>
        <source>Autosave your jobs every time you print.</source>
        <translation>Automatisches Speichern Ihrer Aufträge bei jedem Druckvorgang.</translation>
    </message>
    <message>
        <source>AutoSave the recent sessions</source>
        <translation>Letzte Sitzungen automatisch speichern</translation>
    </message>
    <message>
        <source>Allow negative page margins:</source>
        <translation>Negative Seitenränder erlauben:</translation>
    </message>
    <message>
        <source>Select directory for saved jobs.</source>
        <translation>Verzeichnis für gespeicherte Aufträge auswählen.</translation>
    </message>
    <message>
        <source>Directory for saved sessions:</source>
        <translation>Verzeichnis für gespeicherte Sitzungen:</translation>
    </message>
</context>
<context>
    <name>ExportToPdf</name>
    <message>
        <source>Print to PDF</source>
        <translation>In PDF drucken</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <source>Output file:</source>
        <translation>Ausgabedatei:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Meta info</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <source> The name of the person who created the document.</source>
        <translation>Name des Autors, der das Dokument erstellt hat.</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Betreff:</translation>
    </message>
    <message>
        <source> The subject of the document.</source>
        <translation>Der Betreff des Dokuments.</translation>
    </message>
    <message>
        <source> Keywords associated with the document.</source>
        <translation>Schlüsselwörter des Dokuments.</translation>
    </message>
    <message>
        <source>Keywords:</source>
        <translation>Schlüsselwörter:</translation>
    </message>
    <message>
        <source>PDF files (*.pdf);;All files (*.*)</source>
        <translation>PDF-Dateien (*.pdf);;Alle Dateien (*.*)</translation>
    </message>
    <message>
        <source>Overwrite file?</source>
        <translation>Datei überschreiben?</translation>
    </message>
    <message>
        <source>A file named &quot;%1&quot; already exists.
Are you sure you want to overwrite it?</source>
        <translation>Eine Datei &quot;%1&quot; existiert bereits.
Sind Sie sicher, dass diese überschrieben werden soll?</translation>
    </message>
    <message>
        <source> The document&apos;s title.</source>
        <translation>Der Titel des Dokuments.</translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <source>%1 pages</source>
        <translation>%1 Seiten</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Konfiguration</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Gestaltung (Layout)</translation>
    </message>
    <message>
        <source>1 up</source>
        <translation>1 Seite</translation>
    </message>
    <message>
        <source>2 up</source>
        <translation>2 Seiten</translation>
    </message>
    <message>
        <source>Booklet</source>
        <translation>Broschüre</translation>
    </message>
    <message>
        <source>Print on both sides of a sheet.</source>
        <comment>MainForm::Double-sided checkbox tooltip</comment>
        <translation>Doppelseitiger Druck.</translation>
    </message>
    <message>
        <source>Double-sided</source>
        <comment>MainForm::Double-sided checkbox</comment>
        <translation>Doppelseitig</translation>
    </message>
    <message>
        <source>Jobs</source>
        <translation>Druckaufträge</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Drucker</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Konfigurieren...</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Werkzeugleiste</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>Drucke&amp;n</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>B&amp;eenden</translation>
    </message>
    <message>
        <source>Print and Close</source>
        <translation>Drucken und Beenden</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Strg+P</translation>
    </message>
    <message>
        <source>Next sheet</source>
        <translation>Nächstes Blatt</translation>
    </message>
    <message>
        <source>Previous sheet</source>
        <translation>Vorheriges Blatt</translation>
    </message>
    <message>
        <source>About Boomaga</source>
        <translation>Über Boomaga</translation>
    </message>
    <message>
        <source>Boomaga</source>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>%v of %m</source>
        <comment>Format for QProgressBar (http://qt-project.org/doc/qt-4.8/qprogressbar.html#format-prop)</comment>
        <translation>%v von %m</translation>
    </message>
    <message>
        <source>Print the all pages on %1.</source>
        <translation>Alle Seiten auf %1 drucken.</translation>
    </message>
    <message>
        <source>Print the odd pages on %1.&lt;p&gt;When finished, turn the pages, insert them into the printer&lt;br&gt;and click the Continue button.</source>
        <translation>Ungerade Seitenzahlen auf %1 drucken.&lt;p&gt;Wenn der Ausdruck beendet ist, Seiten umdrehen, wieder in den Drucker einlegen&lt;br&gt;und die Schaltfläche Weiter betätigen.</translation>
    </message>
    <message>
        <source>Print the even pages on %1.</source>
        <translation>Gerade Seitenzahlen auf %1 drucken.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <comment>Status bar</comment>
        <translation>%1 Seiten</translation>
    </message>
    <message>
        <source>%1 page</source>
        <comment>Status bar</comment>
        <translation>%1 Seite</translation>
    </message>
    <message>
        <source>%1 sheets</source>
        <comment>Status bar</comment>
        <translation>%1 Blätter</translation>
    </message>
    <message>
        <source>%1 sheet</source>
        <comment>Status bar</comment>
        <translation>%1 Blatt</translation>
    </message>
    <message>
        <source>Sheet %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Blatt %1 von %2</translation>
    </message>
    <message>
        <source>Insert blank page after this page</source>
        <translation>Leere Seite nach dieser Seite einfügen</translation>
    </message>
    <message>
        <source>Delete this page</source>
        <translation>Diese Seite löschen</translation>
    </message>
    <message>
        <source>Undo delete</source>
        <translation>Rückgängig löschen</translation>
    </message>
    <message>
        <source>Insert blank page before this page</source>
        <translation>Leere Seite vor dieser Seite einfügen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Save project</source>
        <translation>Projekt speichern</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Strg+S</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Speichern unter...</translation>
    </message>
    <message>
        <source>Save project under a new name</source>
        <translation>Projekt unter einem neuen Namen speichern</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Strg+Umschalt+S</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Öffnen...</translation>
    </message>
    <message>
        <source>Open an existing project</source>
        <translation>Ein bestehendes Projekt öffnen</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Strg+O</translation>
    </message>
    <message>
        <source>Page %1</source>
        <comment>'Undo deletion' menu item</comment>
        <translation>Seite %1</translation>
    </message>
    <message>
        <source>Boomaga files (*.boo);;All files (*.*)</source>
        <translation>Boomaga-Dateien (*.boo);;Alle Dateien (*.*)</translation>
    </message>
    <message>
        <source>Project saved successfully.</source>
        <translation>Projekt erfolgreich gespeichert</translation>
    </message>
    <message>
        <source>All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)</source>
        <translation>Alle unterstützten Dateien (*.pdf *.boo);;Boomaga-Dateien (*.boo);;PDF-Dateien (*.pdf);;Alle Dateien (*.*)</translation>
    </message>
    <message>
        <source>4 up horizontal</source>
        <translation>4 Blätter pro Seite (Querformat)</translation>
    </message>
    <message>
        <source>4 up vertical</source>
        <translation>4 Blätter pro Seite (Hochformat)</translation>
    </message>
    <message>
        <source>8 up horizontal</source>
        <translation>8 Blätter pro Seite (Querformat)</translation>
    </message>
    <message>
        <source>8 up vertical</source>
        <translation>8 Blätter pro Seite (Hochformat)</translation>
    </message>
    <message>
        <source>Start new booklet from this page</source>
        <translation>Neue Broschüre ab dieser Seite beginnen</translation>
    </message>
    <message>
        <source>Don&apos;t start new booklet from this page</source>
        <translation>Keine neue Broschüre ab dieser Seite beginnen</translation>
    </message>
    <message>
        <source>Rotate page to the left</source>
        <translation>Seite nach links drehen</translation>
    </message>
    <message>
        <source>Rotate page to the right</source>
        <translation>Seite nach rechts drehen</translation>
    </message>
    <message>
        <source>Rename job</source>
        <translation>Druckauftrag umbenennen</translation>
    </message>
    <message>
        <source>Rotate job to the left</source>
        <translation>Druckauftrag nach links drehen</translation>
    </message>
    <message>
        <source>Rotate job to the right</source>
        <translation>Druckauftrag nach rechts drehen</translation>
    </message>
    <message>
        <source>Job title:</source>
        <translation>Titel des Druckauftrags:</translation>
    </message>
    <message>
        <source>Export the project to PDF</source>
        <translation>Das Projekt als PDF exportieren</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Strg+E</translation>
    </message>
    <message>
        <source>Clone job...</source>
        <translation>Druckauftrag klonen...</translation>
    </message>
    <message>
        <source>Clone job</source>
        <translation>Druckauftrag klonen</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Anzahl der Kopien:</translation>
    </message>
    <message>
        <source>Print with options...</source>
        <translation>Mit Optionen drucken...</translation>
    </message>
    <message>
        <source>Select number of copies before printing.</source>
        <translation>Wählen Sie die Anzahl der Kopien vor dem Drucken aus.</translation>
    </message>
    <message>
        <source>Ctrl+Shift+P</source>
        <translation>Strg+Umschalt+P</translation>
    </message>
    <message>
        <source>Sub-booklets</source>
        <translation>Broschüre aufteilen (sub-booklets)</translation>
    </message>
    <message>
        <source>Undo delete page</source>
        <translation>Gelöschte Seite wiederherstellen</translation>
    </message>
    <message>
        <source>Page %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Seite %1 von %2</translation>
    </message>
    <message>
        <source>Recent files</source>
        <translation>Letzte Dateien</translation>
    </message>
    <message>
        <source>&amp;Edit page</source>
        <translation>&amp;Seite bearbeiten</translation>
    </message>
    <message>
        <source>Edit &amp;job</source>
        <translation>&amp;Auftrag bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Export to PDF...</source>
        <translation>Als &amp;PDF exportieren...</translation>
    </message>
    <message>
        <source>Delete pages until the end of the job</source>
        <translation>Seiten ab hier bis zum Ende löschen</translation>
    </message>
    <message>
        <source>Delete current job</source>
        <translation>Aktuellen Auftrag löschen</translation>
    </message>
    <message>
        <source>Auto saving</source>
        <translation>Automatisches Speichern</translation>
    </message>
    <message>
        <source>I can&apos;t create directory &quot;%1&quot;</source>
        <translation>Ich kann das Verzeichnis &quot;%1&quot; nicht erstellen</translation>
    </message>
    <message>
        <source>%1 %2: Page %3</source>
        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
        <translation>%1 %2: Seite %3</translation>
    </message>
</context>
<context>
    <name>PdfMerger</name>
    <message>
        <source>I can&apos;t write file &quot;%1&quot;</source>
        <translation>Datei &quot;%1&quot; konnte nicht geschrieben werden</translation>
    </message>
</context>
<context>
    <name>PrintDialog</name>
    <message>
        <source>Print document</source>
        <translation>Dokument drucken</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Anzahl der Kopien:</translation>
    </message>
    <message>
        <source>Collate copies:</source>
        <translation>Kopien sortieren:</translation>
    </message>
</context>
<context>
    <name>PrinterSettings</name>
    <message>
        <source>Margins (mm)</source>
        <translation>Ränder (mm)</translation>
    </message>
    <message>
        <source>Right:</source>
        <translation>Rechts:</translation>
    </message>
    <message>
        <source>Bottom:</source>
        <translation>Unten:</translation>
    </message>
    <message>
        <source>Internal:</source>
        <translation>Intern:</translation>
    </message>
    <message>
        <source>Left:</source>
        <translation>Links:</translation>
    </message>
    <message>
        <source>Top:</source>
        <translation>Oben:</translation>
    </message>
    <message>
        <source>Draw border</source>
        <translation>Rahmen anzeigen</translation>
    </message>
    <message>
        <source>Print in reverse order</source>
        <translation>In umgekehrter Reihenfolge drucken</translation>
    </message>
    <message>
        <source>Printer has duplexer</source>
        <translation>Duplex-Drucker vorhanden</translation>
    </message>
    <message>
        <source>Manual with reverse (suitable for most printers)</source>
        <translation>Manuell mit umgekehrter Reihenfolge (für die meisten Drucker geeignet)</translation>
    </message>
    <message>
        <source>Manual without reverse</source>
        <translation>Manuell ohne umgekehrte Reihenfolge</translation>
    </message>
    <message>
        <source>Preferences of &quot;%1&quot;</source>
        <translation>Einstellungen von &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Profiles</source>
        <translation>Profile</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>Auf Standardeinstellung zurücksetzen</translation>
    </message>
    <message>
        <source>Profile %1</source>
        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
        <translation>Profil %1</translation>
    </message>
    <message>
        <source>Color mode:</source>
        <translation>Farbmodus:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Force grayscale</source>
        <translation>Graustufen erzwingen</translation>
    </message>
    <message>
        <source>Force color</source>
        <translation>Farbe erzwingen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Print on both sides</source>
        <translation>Doppelseitiger Druck</translation>
    </message>
    <message>
        <source>Flip on short edge</source>
        <translation>An kurzer Kante umdrehen</translation>
    </message>
    <message>
        <source>Flip on long edge</source>
        <translation>An langer Kante umdrehen</translation>
    </message>
</context>
<context>
    <name>Project</name>
    <message>
        <source>Boomaga</source>
        <comment>Error message title</comment>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Datei &apos;%1&apos; konnte nicht geschrieben werden</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
        <translation>Ich kann die Datei &quot;%1&quot; nicht öffnen (keine solche Datei oder Verzeichnis)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
        <translation>Ich kann die Datei &quot;%1&quot; nicht öffnen (Zugriff verweigert)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <translation>Ich kann die Datei &quot;%1&quot; nicht öffnen</translation>
    </message>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
        <translation>Ich kann die Datei &quot;%1&quot; nicht lesen, weil ihr Dateityp entweder nicht unterstützt wird oder die Datei beschädigt wurde.</translation>
    </message>
</context>
<context>
    <name>ProjectFile</name>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <translation>Ich kann die Datei &quot;%1&quot; nicht öffnen</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Ich kann nicht in die Datei &apos;%1&apos; schreiben</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>I can&apos;t read from file &apos;%1&apos;</source>
        <translation>Ich kann nicht aus der Datei &apos;%1&apos; lesen</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Ich kann nicht in die Datei &apos;%1&apos; schreiben</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Unbenannt</translation>
    </message>
    <message>
        <source>Default</source>
        <comment>Printer profile default name</comment>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>~/Untitled.pdf</source>
        <translation>~/Unbenannt.pdf</translation>
    </message>
</context>
<context>
    <name>SubBookletView</name>
    <message>
        <source>Sub-booklet %1</source>
        <translation>Aufgeteilte Broschüre (sub-booklet) %1</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <translation>%1 Seiten</translation>
    </message>
</context>
<context>
    <name>TmpPdfFile</name>
    <message>
        <source>I can&apos;t create temporary file &quot;%1&quot;</source>
        <translation>Temporäre Datei &quot;%1&quot; konnte nicht erstellt werden</translation>
    </message>
    <message>
        <source>Something is wrong. I can't find boomagamerger program.
Please reinstall me.</source>
        <translation>Irgendetwas stimmt hier nicht. Das Programm boomagamerger konnte nicht gefunden werden.
Bitte neu installieren.</translation>
    </message>
    <message>
        <source>I can&apos;t read file &apos;%1&apos;</source>
        <translation>Datei &apos;%1&apos; konnte nicht gelesen werden</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Datei &apos;%1&apos; konnte nicht geschrieben werden</translation>
    </message>
</context>
</TS>